@@ -1,6 +1,6 @@
 import click
 import heflow.sklearn
-import mlflow.sklearn
+import mlflow
 import sklearn.datasets
 import sklearn.linear_model
 import sklearn.metrics
